glew/generated/lib_glad/lib_glad_amd_sparse_texture library

Functions

glTexStorageSparseAmd(int target, int internalFormat, int width, int height, int depth, int layers, int flags) → void
define glTexStorageSparseAMD GLEW_GET_FUN(__glewTexStorageSparseAMD) GLEW_FUN_EXPORT PFNGLTEXSTORAGESPARSEAMDPROC __glewTexStorageSparseAMD typedef void (GLAPIENTRY * PFNGLTEXSTORAGESPARSEAMDPROC) (GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)
glTextureStorageSparseAmd(int texture, int target, int internalFormat, int width, int height, int depth, int layers, int flags) → void
define glTextureStorageSparseAMD GLEW_GET_FUN(__glewTextureStorageSparseAMD) GLEW_FUN_EXPORT PFNGLTEXTURESTORAGESPARSEAMDPROC __glewTextureStorageSparseAMD typedef void (GLAPIENTRY * PFNGLTEXTURESTORAGESPARSEAMDPROC) (GLuint texture, GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)