glew/generated/lib_glad/lib_glad_arb_geometry_shader4 library

Functions

glFramebufferTextureArb(int target, int attachment, int texture, int level) → void
define glFramebufferTextureARB GLEW_GET_FUN(__glewFramebufferTextureARB) GLEW_FUN_EXPORT PFNGLFRAMEBUFFERTEXTUREARBPROC __glewFramebufferTextureARB typedef void (GLAPIENTRY * PFNGLFRAMEBUFFERTEXTUREARBPROC) (GLenum target, GLenum attachment, GLuint texture, GLint level)
glFramebufferTextureFaceArb(int target, int attachment, int texture, int level, int face) → void
define glFramebufferTextureFaceARB GLEW_GET_FUN(__glewFramebufferTextureFaceARB) GLEW_FUN_EXPORT PFNGLFRAMEBUFFERTEXTUREFACEARBPROC __glewFramebufferTextureFaceARB typedef void (GLAPIENTRY * PFNGLFRAMEBUFFERTEXTUREFACEARBPROC) (GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)
glFramebufferTextureLayerArb(int target, int attachment, int texture, int level, int layer) → void
define glFramebufferTextureLayerARB GLEW_GET_FUN(__glewFramebufferTextureLayerARB) GLEW_FUN_EXPORT PFNGLFRAMEBUFFERTEXTURELAYERARBPROC __glewFramebufferTextureLayerARB typedef void (GLAPIENTRY * PFNGLFRAMEBUFFERTEXTURELAYERARBPROC) (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
glProgramParameteriArb(int program, int pname, int value) → void
define glProgramParameteriARB GLEW_GET_FUN(__glewProgramParameteriARB) GLEW_FUN_EXPORT PFNGLPROGRAMPARAMETERIARBPROC __glewProgramParameteriARB typedef void (GLAPIENTRY * PFNGLPROGRAMPARAMETERIARBPROC) (GLuint program, GLenum pname, GLint value)