glCopyTexSubImage3Dnv function
void
glCopyTexSubImage3Dnv()
define glCopyTexSubImage3DNV GLEW_GET_FUN(__glewCopyTexSubImage3DNV)
GLEW_FUN_EXPORT PFNGLCOPYTEXSUBIMAGE3DNVPROC __glewCopyTexSubImage3DNV
typedef void (GLAPIENTRY * PFNGLCOPYTEXSUBIMAGE3DNVPROC) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
Implementation
void glCopyTexSubImage3Dnv(int target, int level, int xoffset, int yoffset,
int zoffset, int x, int y, int width, int height) {
final glCopyTexSubImage3DnvAsFunction = _glCopyTexSubImage3Dnv
.cast<
NativeFunction<
Void Function(
Uint32 target,
Int32 level,
Int32 xoffset,
Int32 yoffset,
Int32 zoffset,
Int32 x,
Int32 y,
Uint32 width,
Uint32 height)>>()
.asFunction<
void Function(int target, int level, int xoffset, int yoffset,
int zoffset, int x, int y, int width, int height)>();
return glCopyTexSubImage3DnvAsFunction(
target, level, xoffset, yoffset, zoffset, x, y, width, height);
}