glDrawRangeElements function
void
glDrawRangeElements()
define glDrawRangeElements GLEW_GET_FUN(__glewDrawRangeElements)
GLEW_FUN_EXPORT PFNGLDRAWRANGEELEMENTSPROC __glewDrawRangeElements
typedef void (GLAPIENTRY * PFNGLDRAWRANGEELEMENTSPROC) (GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
Implementation
void glDrawRangeElements(
int mode, int start, int end, int count, int type, Pointer<Void> indices) {
final glDrawRangeElementsAsFunction = _glDrawRangeElements
.cast<
NativeFunction<
Void Function(Uint32 mode, Uint32 start, Uint32 end, Uint32 count,
Uint32 type, Pointer<Void> indices)>>()
.asFunction<
void Function(int mode, int start, int end, int count, int type,
Pointer<Void> indices)>();
return glDrawRangeElementsAsFunction(mode, start, end, count, type, indices);
}