glew/generated/lib_glad/lib_glad_arb_direct_state_access
library
Functions
-
glBindTextureUnit(int unit, int texture)
→ void
-
define glBindTextureUnit GLEW_GET_FUN(__glewBindTextureUnit)
GLEW_FUN_EXPORT PFNGLBINDTEXTUREUNITPROC __glewBindTextureUnit
typedef void (GLAPIENTRY * PFNGLBINDTEXTUREUNITPROC) (GLuint unit, GLuint texture)
-
glBlitNamedFramebuffer(int readFramebuffer, int drawFramebuffer, int srcX0, int srcY0, int srcX1, int srcY1, int dstX0, int dstY0, int dstX1, int dstY1, int mask, int filter)
→ void
-
define glBlitNamedFramebuffer GLEW_GET_FUN(__glewBlitNamedFramebuffer)
GLEW_FUN_EXPORT PFNGLBLITNAMEDFRAMEBUFFERPROC __glewBlitNamedFramebuffer
typedef void (GLAPIENTRY * PFNGLBLITNAMEDFRAMEBUFFERPROC) (GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
-
glCheckNamedFramebufferStatus(int framebuffer, int target)
→ int
-
define glCheckNamedFramebufferStatus GLEW_GET_FUN(__glewCheckNamedFramebufferStatus)
GLEW_FUN_EXPORT PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC __glewCheckNamedFramebufferStatus
typedef GLenum (GLAPIENTRY * PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC) (GLuint framebuffer, GLenum target)
-
glClearNamedBufferData(int buffer, int internalformat, int format, int type, Pointer<Void> data)
→ void
-
define glClearNamedBufferData GLEW_GET_FUN(__glewClearNamedBufferData)
GLEW_FUN_EXPORT PFNGLCLEARNAMEDBUFFERDATAPROC __glewClearNamedBufferData
typedef void (GLAPIENTRY * PFNGLCLEARNAMEDBUFFERDATAPROC) (GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
-
glClearNamedBufferSubData(int buffer, int internalformat, int offset, int size, int format, int type, Pointer<Void> data)
→ void
-
define glClearNamedBufferSubData GLEW_GET_FUN(__glewClearNamedBufferSubData)
GLEW_FUN_EXPORT PFNGLCLEARNAMEDBUFFERSUBDATAPROC __glewClearNamedBufferSubData
typedef void (GLAPIENTRY * PFNGLCLEARNAMEDBUFFERSUBDATAPROC) (GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
-
glClearNamedFramebufferfi(int framebuffer, int buffer, int drawbuffer, double depth, int stencil)
→ void
-
define glClearNamedFramebufferfi GLEW_GET_FUN(__glewClearNamedFramebufferfi)
GLEW_FUN_EXPORT PFNGLCLEARNAMEDFRAMEBUFFERFIPROC __glewClearNamedFramebufferfi
typedef void (GLAPIENTRY * PFNGLCLEARNAMEDFRAMEBUFFERFIPROC) (GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
-
glClearNamedFramebufferfv(int framebuffer, int buffer, int drawbuffer, Pointer<Float> value)
→ void
-
define glClearNamedFramebufferfv GLEW_GET_FUN(__glewClearNamedFramebufferfv)
GLEW_FUN_EXPORT PFNGLCLEARNAMEDFRAMEBUFFERFVPROC __glewClearNamedFramebufferfv
typedef void (GLAPIENTRY * PFNGLCLEARNAMEDFRAMEBUFFERFVPROC) (GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat* value)
-
glClearNamedFramebufferiv(int framebuffer, int buffer, int drawbuffer, Pointer<Int32> value)
→ void
-
define glClearNamedFramebufferiv GLEW_GET_FUN(__glewClearNamedFramebufferiv)
GLEW_FUN_EXPORT PFNGLCLEARNAMEDFRAMEBUFFERIVPROC __glewClearNamedFramebufferiv
typedef void (GLAPIENTRY * PFNGLCLEARNAMEDFRAMEBUFFERIVPROC) (GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint* value)
-
glClearNamedFramebufferuiv(int framebuffer, int buffer, int drawbuffer, Pointer<Uint32> value)
→ void
-
define glClearNamedFramebufferuiv GLEW_GET_FUN(__glewClearNamedFramebufferuiv)
GLEW_FUN_EXPORT PFNGLCLEARNAMEDFRAMEBUFFERUIVPROC __glewClearNamedFramebufferuiv
typedef void (GLAPIENTRY * PFNGLCLEARNAMEDFRAMEBUFFERUIVPROC) (GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint* value)
-
glCompressedTextureSubImage1D(int texture, int level, int xoffset, int width, int format, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTextureSubImage1D GLEW_GET_FUN(__glewCompressedTextureSubImage1D)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXTURESUBIMAGE1DPROC __glewCompressedTextureSubImage1D
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXTURESUBIMAGE1DPROC) (GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
-
glCompressedTextureSubImage2D(int texture, int level, int xoffset, int yoffset, int width, int height, int format, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTextureSubImage2D GLEW_GET_FUN(__glewCompressedTextureSubImage2D)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXTURESUBIMAGE2DPROC __glewCompressedTextureSubImage2D
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXTURESUBIMAGE2DPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
-
glCompressedTextureSubImage3D(int texture, int level, int xoffset, int yoffset, int zoffset, int width, int height, int depth, int format, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTextureSubImage3D GLEW_GET_FUN(__glewCompressedTextureSubImage3D)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXTURESUBIMAGE3DPROC __glewCompressedTextureSubImage3D
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXTURESUBIMAGE3DPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
-
glCopyNamedBufferSubData(int readBuffer, int writeBuffer, int readOffset, int writeOffset, int size)
→ void
-
define glCopyNamedBufferSubData GLEW_GET_FUN(__glewCopyNamedBufferSubData)
GLEW_FUN_EXPORT PFNGLCOPYNAMEDBUFFERSUBDATAPROC __glewCopyNamedBufferSubData
typedef void (GLAPIENTRY * PFNGLCOPYNAMEDBUFFERSUBDATAPROC) (GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
-
glCopyTextureSubImage1D(int texture, int level, int xoffset, int x, int y, int width)
→ void
-
define glCopyTextureSubImage1D GLEW_GET_FUN(__glewCopyTextureSubImage1D)
GLEW_FUN_EXPORT PFNGLCOPYTEXTURESUBIMAGE1DPROC __glewCopyTextureSubImage1D
typedef void (GLAPIENTRY * PFNGLCOPYTEXTURESUBIMAGE1DPROC) (GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
-
glCopyTextureSubImage2D(int texture, int level, int xoffset, int yoffset, int x, int y, int width, int height)
→ void
-
define glCopyTextureSubImage2D GLEW_GET_FUN(__glewCopyTextureSubImage2D)
GLEW_FUN_EXPORT PFNGLCOPYTEXTURESUBIMAGE2DPROC __glewCopyTextureSubImage2D
typedef void (GLAPIENTRY * PFNGLCOPYTEXTURESUBIMAGE2DPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
-
glCopyTextureSubImage3D(int texture, int level, int xoffset, int yoffset, int zoffset, int x, int y, int width, int height)
→ void
-
define glCopyTextureSubImage3D GLEW_GET_FUN(__glewCopyTextureSubImage3D)
GLEW_FUN_EXPORT PFNGLCOPYTEXTURESUBIMAGE3DPROC __glewCopyTextureSubImage3D
typedef void (GLAPIENTRY * PFNGLCOPYTEXTURESUBIMAGE3DPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
-
glCreateBuffers(int n, Pointer<Uint32> buffers)
→ void
-
define glCreateBuffers GLEW_GET_FUN(__glewCreateBuffers)
GLEW_FUN_EXPORT PFNGLCREATEBUFFERSPROC __glewCreateBuffers
typedef void (GLAPIENTRY * PFNGLCREATEBUFFERSPROC) (GLsizei n, GLuint* buffers)
-
glCreateFramebuffers(int n, Pointer<Uint32> framebuffers)
→ void
-
define glCreateFramebuffers GLEW_GET_FUN(__glewCreateFramebuffers)
GLEW_FUN_EXPORT PFNGLCREATEFRAMEBUFFERSPROC __glewCreateFramebuffers
typedef void (GLAPIENTRY * PFNGLCREATEFRAMEBUFFERSPROC) (GLsizei n, GLuint* framebuffers)
-
glCreateProgramPipelines(int n, Pointer<Uint32> pipelines)
→ void
-
define glCreateProgramPipelines GLEW_GET_FUN(__glewCreateProgramPipelines)
GLEW_FUN_EXPORT PFNGLCREATEPROGRAMPIPELINESPROC __glewCreateProgramPipelines
typedef void (GLAPIENTRY * PFNGLCREATEPROGRAMPIPELINESPROC) (GLsizei n, GLuint* pipelines)
-
glCreateQueries(int target, int n, Pointer<Uint32> ids)
→ void
-
define glCreateQueries GLEW_GET_FUN(__glewCreateQueries)
GLEW_FUN_EXPORT PFNGLCREATEQUERIESPROC __glewCreateQueries
typedef void (GLAPIENTRY * PFNGLCREATEQUERIESPROC) (GLenum target, GLsizei n, GLuint* ids)
-
glCreateRenderbuffers(int n, Pointer<Uint32> renderbuffers)
→ void
-
define glCreateRenderbuffers GLEW_GET_FUN(__glewCreateRenderbuffers)
GLEW_FUN_EXPORT PFNGLCREATERENDERBUFFERSPROC __glewCreateRenderbuffers
typedef void (GLAPIENTRY * PFNGLCREATERENDERBUFFERSPROC) (GLsizei n, GLuint* renderbuffers)
-
glCreateSamplers(int n, Pointer<Uint32> samplers)
→ void
-
define glCreateSamplers GLEW_GET_FUN(__glewCreateSamplers)
GLEW_FUN_EXPORT PFNGLCREATESAMPLERSPROC __glewCreateSamplers
typedef void (GLAPIENTRY * PFNGLCREATESAMPLERSPROC) (GLsizei n, GLuint* samplers)
-
glCreateTextures(int target, int n, Pointer<Uint32> textures)
→ void
-
define glCreateTextures GLEW_GET_FUN(__glewCreateTextures)
GLEW_FUN_EXPORT PFNGLCREATETEXTURESPROC __glewCreateTextures
typedef void (GLAPIENTRY * PFNGLCREATETEXTURESPROC) (GLenum target, GLsizei n, GLuint* textures)
-
glCreateTransformFeedbacks(int n, Pointer<Uint32> ids)
→ void
-
define glCreateTransformFeedbacks GLEW_GET_FUN(__glewCreateTransformFeedbacks)
GLEW_FUN_EXPORT PFNGLCREATETRANSFORMFEEDBACKSPROC __glewCreateTransformFeedbacks
typedef void (GLAPIENTRY * PFNGLCREATETRANSFORMFEEDBACKSPROC) (GLsizei n, GLuint* ids)
-
glCreateVertexArrays(int n, Pointer<Uint32> arrays)
→ void
-
define glCreateVertexArrays GLEW_GET_FUN(__glewCreateVertexArrays)
GLEW_FUN_EXPORT PFNGLCREATEVERTEXARRAYSPROC __glewCreateVertexArrays
typedef void (GLAPIENTRY * PFNGLCREATEVERTEXARRAYSPROC) (GLsizei n, GLuint* arrays)
-
glDisableVertexArrayAttrib(int vaobj, int index)
→ void
-
define glDisableVertexArrayAttrib GLEW_GET_FUN(__glewDisableVertexArrayAttrib)
GLEW_FUN_EXPORT PFNGLDISABLEVERTEXARRAYATTRIBPROC __glewDisableVertexArrayAttrib
typedef void (GLAPIENTRY * PFNGLDISABLEVERTEXARRAYATTRIBPROC) (GLuint vaobj, GLuint index)
-
glEnableVertexArrayAttrib(int vaobj, int index)
→ void
-
define glEnableVertexArrayAttrib GLEW_GET_FUN(__glewEnableVertexArrayAttrib)
GLEW_FUN_EXPORT PFNGLENABLEVERTEXARRAYATTRIBPROC __glewEnableVertexArrayAttrib
typedef void (GLAPIENTRY * PFNGLENABLEVERTEXARRAYATTRIBPROC) (GLuint vaobj, GLuint index)
-
glFlushMappedNamedBufferRange(int buffer, int offset, int length)
→ void
-
define glFlushMappedNamedBufferRange GLEW_GET_FUN(__glewFlushMappedNamedBufferRange)
GLEW_FUN_EXPORT PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEPROC __glewFlushMappedNamedBufferRange
typedef void (GLAPIENTRY * PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEPROC) (GLuint buffer, GLintptr offset, GLsizeiptr length)
-
glGenerateTextureMipmap(int texture)
→ void
-
define glGenerateTextureMipmap GLEW_GET_FUN(__glewGenerateTextureMipmap)
GLEW_FUN_EXPORT PFNGLGENERATETEXTUREMIPMAPPROC __glewGenerateTextureMipmap
typedef void (GLAPIENTRY * PFNGLGENERATETEXTUREMIPMAPPROC) (GLuint texture)
-
glGetCompressedTextureImage(int texture, int level, int bufSize, Pointer<Void> pixels)
→ void
-
define glGetCompressedTextureImage GLEW_GET_FUN(__glewGetCompressedTextureImage)
GLEW_FUN_EXPORT PFNGLGETCOMPRESSEDTEXTUREIMAGEPROC __glewGetCompressedTextureImage
typedef void (GLAPIENTRY * PFNGLGETCOMPRESSEDTEXTUREIMAGEPROC) (GLuint texture, GLint level, GLsizei bufSize, void *pixels)
-
glGetNamedBufferParameteri64v(int buffer, int pname, Pointer<Int64> params)
→ void
-
define glGetNamedBufferParameteri64v GLEW_GET_FUN(__glewGetNamedBufferParameteri64v)
GLEW_FUN_EXPORT PFNGLGETNAMEDBUFFERPARAMETERI64VPROC __glewGetNamedBufferParameteri64v
typedef void (GLAPIENTRY * PFNGLGETNAMEDBUFFERPARAMETERI64VPROC) (GLuint buffer, GLenum pname, GLint64* params)
-
glGetNamedBufferParameteriv(int buffer, int pname, Pointer<Int32> params)
→ void
-
define glGetNamedBufferParameteriv GLEW_GET_FUN(__glewGetNamedBufferParameteriv)
GLEW_FUN_EXPORT PFNGLGETNAMEDBUFFERPARAMETERIVPROC __glewGetNamedBufferParameteriv
typedef void (GLAPIENTRY * PFNGLGETNAMEDBUFFERPARAMETERIVPROC) (GLuint buffer, GLenum pname, GLint* params)
-
glGetNamedBufferPointerv(int buffer, int pname, Pointer<Pointer<Void>> params)
→ void
-
define glGetNamedBufferPointerv GLEW_GET_FUN(__glewGetNamedBufferPointerv)
GLEW_FUN_EXPORT PFNGLGETNAMEDBUFFERPOINTERVPROC __glewGetNamedBufferPointerv
typedef void (GLAPIENTRY * PFNGLGETNAMEDBUFFERPOINTERVPROC) (GLuint buffer, GLenum pname, void** params)
-
glGetNamedBufferSubData(int buffer, int offset, int size, Pointer<Void> data)
→ void
-
define glGetNamedBufferSubData GLEW_GET_FUN(__glewGetNamedBufferSubData)
GLEW_FUN_EXPORT PFNGLGETNAMEDBUFFERSUBDATAPROC __glewGetNamedBufferSubData
typedef void (GLAPIENTRY * PFNGLGETNAMEDBUFFERSUBDATAPROC) (GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
-
glGetNamedFramebufferAttachmentParameteriv(int framebuffer, int attachment, int pname, Pointer<Int32> params)
→ void
-
define glGetNamedFramebufferAttachmentParameteriv GLEW_GET_FUN(__glewGetNamedFramebufferAttachmentParameteriv)
GLEW_FUN_EXPORT PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVPROC __glewGetNamedFramebufferAttachmentParameteriv
typedef void (GLAPIENTRY * PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVPROC) (GLuint framebuffer, GLenum attachment, GLenum pname, GLint* params)
-
glGetNamedFramebufferParameteriv(int framebuffer, int pname, Pointer<Int32> param)
→ void
-
define glGetNamedFramebufferParameteriv GLEW_GET_FUN(__glewGetNamedFramebufferParameteriv)
GLEW_FUN_EXPORT PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVPROC __glewGetNamedFramebufferParameteriv
typedef void (GLAPIENTRY * PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVPROC) (GLuint framebuffer, GLenum pname, GLint* param)
-
glGetNamedRenderbufferParameteriv(int renderbuffer, int pname, Pointer<Int32> params)
→ void
-
define glGetNamedRenderbufferParameteriv GLEW_GET_FUN(__glewGetNamedRenderbufferParameteriv)
GLEW_FUN_EXPORT PFNGLGETNAMEDRENDERBUFFERPARAMETERIVPROC __glewGetNamedRenderbufferParameteriv
typedef void (GLAPIENTRY * PFNGLGETNAMEDRENDERBUFFERPARAMETERIVPROC) (GLuint renderbuffer, GLenum pname, GLint* params)
-
glGetQueryBufferObjecti64v(int id, int buffer, int pname, int offset)
→ void
-
define glGetQueryBufferObjecti64v GLEW_GET_FUN(__glewGetQueryBufferObjecti64v)
GLEW_FUN_EXPORT PFNGLGETQUERYBUFFEROBJECTI64VPROC __glewGetQueryBufferObjecti64v
typedef void (GLAPIENTRY * PFNGLGETQUERYBUFFEROBJECTI64VPROC) (GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
-
glGetQueryBufferObjectiv(int id, int buffer, int pname, int offset)
→ void
-
define glGetQueryBufferObjectiv GLEW_GET_FUN(__glewGetQueryBufferObjectiv)
GLEW_FUN_EXPORT PFNGLGETQUERYBUFFEROBJECTIVPROC __glewGetQueryBufferObjectiv
typedef void (GLAPIENTRY * PFNGLGETQUERYBUFFEROBJECTIVPROC) (GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
-
glGetQueryBufferObjectui64v(int id, int buffer, int pname, int offset)
→ void
-
define glGetQueryBufferObjectui64v GLEW_GET_FUN(__glewGetQueryBufferObjectui64v)
GLEW_FUN_EXPORT PFNGLGETQUERYBUFFEROBJECTUI64VPROC __glewGetQueryBufferObjectui64v
typedef void (GLAPIENTRY * PFNGLGETQUERYBUFFEROBJECTUI64VPROC) (GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
-
glGetQueryBufferObjectuiv(int id, int buffer, int pname, int offset)
→ void
-
define glGetQueryBufferObjectuiv GLEW_GET_FUN(__glewGetQueryBufferObjectuiv)
GLEW_FUN_EXPORT PFNGLGETQUERYBUFFEROBJECTUIVPROC __glewGetQueryBufferObjectuiv
typedef void (GLAPIENTRY * PFNGLGETQUERYBUFFEROBJECTUIVPROC) (GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
-
glGetTextureImage(int texture, int level, int format, int type, int bufSize, Pointer<Void> pixels)
→ void
-
define glGetTextureImage GLEW_GET_FUN(__glewGetTextureImage)
GLEW_FUN_EXPORT PFNGLGETTEXTUREIMAGEPROC __glewGetTextureImage
typedef void (GLAPIENTRY * PFNGLGETTEXTUREIMAGEPROC) (GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
-
glGetTextureLevelParameterfv(int texture, int level, int pname, Pointer<Float> params)
→ void
-
define glGetTextureLevelParameterfv GLEW_GET_FUN(__glewGetTextureLevelParameterfv)
GLEW_FUN_EXPORT PFNGLGETTEXTURELEVELPARAMETERFVPROC __glewGetTextureLevelParameterfv
typedef void (GLAPIENTRY * PFNGLGETTEXTURELEVELPARAMETERFVPROC) (GLuint texture, GLint level, GLenum pname, GLfloat* params)
-
glGetTextureLevelParameteriv(int texture, int level, int pname, Pointer<Int32> params)
→ void
-
define glGetTextureLevelParameteriv GLEW_GET_FUN(__glewGetTextureLevelParameteriv)
GLEW_FUN_EXPORT PFNGLGETTEXTURELEVELPARAMETERIVPROC __glewGetTextureLevelParameteriv
typedef void (GLAPIENTRY * PFNGLGETTEXTURELEVELPARAMETERIVPROC) (GLuint texture, GLint level, GLenum pname, GLint* params)
-
glGetTextureParameterfv(int texture, int pname, Pointer<Float> params)
→ void
-
define glGetTextureParameterfv GLEW_GET_FUN(__glewGetTextureParameterfv)
GLEW_FUN_EXPORT PFNGLGETTEXTUREPARAMETERFVPROC __glewGetTextureParameterfv
typedef void (GLAPIENTRY * PFNGLGETTEXTUREPARAMETERFVPROC) (GLuint texture, GLenum pname, GLfloat* params)
-
glGetTextureParameterIiv(int texture, int pname, Pointer<Int32> params)
→ void
-
define glGetTextureParameterIiv GLEW_GET_FUN(__glewGetTextureParameterIiv)
GLEW_FUN_EXPORT PFNGLGETTEXTUREPARAMETERIIVPROC __glewGetTextureParameterIiv
typedef void (GLAPIENTRY * PFNGLGETTEXTUREPARAMETERIIVPROC) (GLuint texture, GLenum pname, GLint* params)
-
glGetTextureParameterIuiv(int texture, int pname, Pointer<Uint32> params)
→ void
-
define glGetTextureParameterIuiv GLEW_GET_FUN(__glewGetTextureParameterIuiv)
GLEW_FUN_EXPORT PFNGLGETTEXTUREPARAMETERIUIVPROC __glewGetTextureParameterIuiv
typedef void (GLAPIENTRY * PFNGLGETTEXTUREPARAMETERIUIVPROC) (GLuint texture, GLenum pname, GLuint* params)
-
glGetTextureParameteriv(int texture, int pname, Pointer<Int32> params)
→ void
-
define glGetTextureParameteriv GLEW_GET_FUN(__glewGetTextureParameteriv)
GLEW_FUN_EXPORT PFNGLGETTEXTUREPARAMETERIVPROC __glewGetTextureParameteriv
typedef void (GLAPIENTRY * PFNGLGETTEXTUREPARAMETERIVPROC) (GLuint texture, GLenum pname, GLint* params)
-
glGetTransformFeedbacki64V(int xfb, int pname, int index, Pointer<Int64> param)
→ void
-
define glGetTransformFeedbacki64_v GLEW_GET_FUN(__glewGetTransformFeedbacki64_v)
GLEW_FUN_EXPORT PFNGLGETTRANSFORMFEEDBACKI64_VPROC __glewGetTransformFeedbacki64_v
typedef void (GLAPIENTRY * PFNGLGETTRANSFORMFEEDBACKI64_VPROC) (GLuint xfb, GLenum pname, GLuint index, GLint64* param)
-
glGetTransformFeedbackiV(int xfb, int pname, int index, Pointer<Int32> param)
→ void
-
define glGetTransformFeedbacki_v GLEW_GET_FUN(__glewGetTransformFeedbacki_v)
GLEW_FUN_EXPORT PFNGLGETTRANSFORMFEEDBACKI_VPROC __glewGetTransformFeedbacki_v
typedef void (GLAPIENTRY * PFNGLGETTRANSFORMFEEDBACKI_VPROC) (GLuint xfb, GLenum pname, GLuint index, GLint* param)
-
glGetTransformFeedbackiv(int xfb, int pname, Pointer<Int32> param)
→ void
-
define glGetTransformFeedbackiv GLEW_GET_FUN(__glewGetTransformFeedbackiv)
GLEW_FUN_EXPORT PFNGLGETTRANSFORMFEEDBACKIVPROC __glewGetTransformFeedbackiv
typedef void (GLAPIENTRY * PFNGLGETTRANSFORMFEEDBACKIVPROC) (GLuint xfb, GLenum pname, GLint* param)
-
glGetVertexArrayIndexed64iv(int vaobj, int index, int pname, Pointer<Int64> param)
→ void
-
define glGetVertexArrayIndexed64iv GLEW_GET_FUN(__glewGetVertexArrayIndexed64iv)
GLEW_FUN_EXPORT PFNGLGETVERTEXARRAYINDEXED64IVPROC __glewGetVertexArrayIndexed64iv
typedef void (GLAPIENTRY * PFNGLGETVERTEXARRAYINDEXED64IVPROC) (GLuint vaobj, GLuint index, GLenum pname, GLint64* param)
-
glGetVertexArrayIndexediv(int vaobj, int index, int pname, Pointer<Int32> param)
→ void
-
define glGetVertexArrayIndexediv GLEW_GET_FUN(__glewGetVertexArrayIndexediv)
GLEW_FUN_EXPORT PFNGLGETVERTEXARRAYINDEXEDIVPROC __glewGetVertexArrayIndexediv
typedef void (GLAPIENTRY * PFNGLGETVERTEXARRAYINDEXEDIVPROC) (GLuint vaobj, GLuint index, GLenum pname, GLint* param)
-
glGetVertexArrayiv(int vaobj, int pname, Pointer<Int32> param)
→ void
-
define glGetVertexArrayiv GLEW_GET_FUN(__glewGetVertexArrayiv)
GLEW_FUN_EXPORT PFNGLGETVERTEXARRAYIVPROC __glewGetVertexArrayiv
typedef void (GLAPIENTRY * PFNGLGETVERTEXARRAYIVPROC) (GLuint vaobj, GLenum pname, GLint* param)
-
glInvalidateNamedFramebufferData(int framebuffer, int numAttachments, Pointer<Uint32> attachments)
→ void
-
define glInvalidateNamedFramebufferData GLEW_GET_FUN(__glewInvalidateNamedFramebufferData)
GLEW_FUN_EXPORT PFNGLINVALIDATENAMEDFRAMEBUFFERDATAPROC __glewInvalidateNamedFramebufferData
typedef void (GLAPIENTRY * PFNGLINVALIDATENAMEDFRAMEBUFFERDATAPROC) (GLuint framebuffer, GLsizei numAttachments, const GLenum* attachments)
-
glInvalidateNamedFramebufferSubData(int framebuffer, int numAttachments, Pointer<Uint32> attachments, int x, int y, int width, int height)
→ void
-
define glInvalidateNamedFramebufferSubData GLEW_GET_FUN(__glewInvalidateNamedFramebufferSubData)
GLEW_FUN_EXPORT PFNGLINVALIDATENAMEDFRAMEBUFFERSUBDATAPROC __glewInvalidateNamedFramebufferSubData
typedef void (GLAPIENTRY * PFNGLINVALIDATENAMEDFRAMEBUFFERSUBDATAPROC) (GLuint framebuffer, GLsizei numAttachments, const GLenum* attachments, GLint x, GLint y, GLsizei width, GLsizei height)
-
glMapNamedBuffer(int buffer, int access)
→ Pointer<Void>
-
define glMapNamedBuffer GLEW_GET_FUN(__glewMapNamedBuffer)
GLEW_FUN_EXPORT PFNGLMAPNAMEDBUFFERPROC __glewMapNamedBuffer
typedef void * (GLAPIENTRY * PFNGLMAPNAMEDBUFFERPROC) (GLuint buffer, GLenum access)
-
glMapNamedBufferRange(int buffer, int offset, int length, int access)
→ Pointer<Void>
-
define glMapNamedBufferRange GLEW_GET_FUN(__glewMapNamedBufferRange)
GLEW_FUN_EXPORT PFNGLMAPNAMEDBUFFERRANGEPROC __glewMapNamedBufferRange
typedef void * (GLAPIENTRY * PFNGLMAPNAMEDBUFFERRANGEPROC) (GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
-
glNamedBufferData(int buffer, int size, Pointer<Void> data, int usage)
→ void
-
define glNamedBufferData GLEW_GET_FUN(__glewNamedBufferData)
GLEW_FUN_EXPORT PFNGLNAMEDBUFFERDATAPROC __glewNamedBufferData
typedef void (GLAPIENTRY * PFNGLNAMEDBUFFERDATAPROC) (GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
-
glNamedBufferStorage(int buffer, int size, Pointer<Void> data, int flags)
→ void
-
define glNamedBufferStorage GLEW_GET_FUN(__glewNamedBufferStorage)
GLEW_FUN_EXPORT PFNGLNAMEDBUFFERSTORAGEPROC __glewNamedBufferStorage
typedef void (GLAPIENTRY * PFNGLNAMEDBUFFERSTORAGEPROC) (GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
-
glNamedBufferSubData(int buffer, int offset, int size, Pointer<Void> data)
→ void
-
define glNamedBufferSubData GLEW_GET_FUN(__glewNamedBufferSubData)
GLEW_FUN_EXPORT PFNGLNAMEDBUFFERSUBDATAPROC __glewNamedBufferSubData
typedef void (GLAPIENTRY * PFNGLNAMEDBUFFERSUBDATAPROC) (GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
-
glNamedFramebufferDrawBuffer(int framebuffer, int mode)
→ void
-
define glNamedFramebufferDrawBuffer GLEW_GET_FUN(__glewNamedFramebufferDrawBuffer)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERDRAWBUFFERPROC __glewNamedFramebufferDrawBuffer
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERDRAWBUFFERPROC) (GLuint framebuffer, GLenum mode)
-
glNamedFramebufferDrawBuffers(int framebuffer, int n, Pointer<Uint32> bufs)
→ void
-
define glNamedFramebufferDrawBuffers GLEW_GET_FUN(__glewNamedFramebufferDrawBuffers)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERDRAWBUFFERSPROC __glewNamedFramebufferDrawBuffers
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERDRAWBUFFERSPROC) (GLuint framebuffer, GLsizei n, const GLenum* bufs)
-
glNamedFramebufferParameteri(int framebuffer, int pname, int param)
→ void
-
define glNamedFramebufferParameteri GLEW_GET_FUN(__glewNamedFramebufferParameteri)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERPARAMETERIPROC __glewNamedFramebufferParameteri
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERPARAMETERIPROC) (GLuint framebuffer, GLenum pname, GLint param)
-
glNamedFramebufferReadBuffer(int framebuffer, int mode)
→ void
-
define glNamedFramebufferReadBuffer GLEW_GET_FUN(__glewNamedFramebufferReadBuffer)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERREADBUFFERPROC __glewNamedFramebufferReadBuffer
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERREADBUFFERPROC) (GLuint framebuffer, GLenum mode)
-
glNamedFramebufferRenderbuffer(int framebuffer, int attachment, int renderbuffertarget, int renderbuffer)
→ void
-
define glNamedFramebufferRenderbuffer GLEW_GET_FUN(__glewNamedFramebufferRenderbuffer)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERRENDERBUFFERPROC __glewNamedFramebufferRenderbuffer
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERRENDERBUFFERPROC) (GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
-
glNamedFramebufferTexture(int framebuffer, int attachment, int texture, int level)
→ void
-
define glNamedFramebufferTexture GLEW_GET_FUN(__glewNamedFramebufferTexture)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERTEXTUREPROC __glewNamedFramebufferTexture
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERTEXTUREPROC) (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
-
glNamedFramebufferTextureLayer(int framebuffer, int attachment, int texture, int level, int layer)
→ void
-
define glNamedFramebufferTextureLayer GLEW_GET_FUN(__glewNamedFramebufferTextureLayer)
GLEW_FUN_EXPORT PFNGLNAMEDFRAMEBUFFERTEXTURELAYERPROC __glewNamedFramebufferTextureLayer
typedef void (GLAPIENTRY * PFNGLNAMEDFRAMEBUFFERTEXTURELAYERPROC) (GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
-
glNamedRenderbufferStorage(int renderbuffer, int internalformat, int width, int height)
→ void
-
define glNamedRenderbufferStorage GLEW_GET_FUN(__glewNamedRenderbufferStorage)
GLEW_FUN_EXPORT PFNGLNAMEDRENDERBUFFERSTORAGEPROC __glewNamedRenderbufferStorage
typedef void (GLAPIENTRY * PFNGLNAMEDRENDERBUFFERSTORAGEPROC) (GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
-
glNamedRenderbufferStorageMultisample(int renderbuffer, int samples, int internalformat, int width, int height)
→ void
-
define glNamedRenderbufferStorageMultisample GLEW_GET_FUN(__glewNamedRenderbufferStorageMultisample)
GLEW_FUN_EXPORT PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEPROC __glewNamedRenderbufferStorageMultisample
typedef void (GLAPIENTRY * PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEPROC) (GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
-
glTextureBuffer(int texture, int internalformat, int buffer)
→ void
-
define glTextureBuffer GLEW_GET_FUN(__glewTextureBuffer)
GLEW_FUN_EXPORT PFNGLTEXTUREBUFFERPROC __glewTextureBuffer
typedef void (GLAPIENTRY * PFNGLTEXTUREBUFFERPROC) (GLuint texture, GLenum internalformat, GLuint buffer)
-
glTextureBufferRange(int texture, int internalformat, int buffer, int offset, int size)
→ void
-
define glTextureBufferRange GLEW_GET_FUN(__glewTextureBufferRange)
GLEW_FUN_EXPORT PFNGLTEXTUREBUFFERRANGEPROC __glewTextureBufferRange
typedef void (GLAPIENTRY * PFNGLTEXTUREBUFFERRANGEPROC) (GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
-
glTextureParameterf(int texture, int pname, double param)
→ void
-
define glTextureParameterf GLEW_GET_FUN(__glewTextureParameterf)
GLEW_FUN_EXPORT PFNGLTEXTUREPARAMETERFPROC __glewTextureParameterf
typedef void (GLAPIENTRY * PFNGLTEXTUREPARAMETERFPROC) (GLuint texture, GLenum pname, GLfloat param)
-
glTextureParameterfv(int texture, int pname, Pointer<Float> param)
→ void
-
define glTextureParameterfv GLEW_GET_FUN(__glewTextureParameterfv)
GLEW_FUN_EXPORT PFNGLTEXTUREPARAMETERFVPROC __glewTextureParameterfv
typedef void (GLAPIENTRY * PFNGLTEXTUREPARAMETERFVPROC) (GLuint texture, GLenum pname, const GLfloat* param)
-
glTextureParameteri(int texture, int pname, int param)
→ void
-
define glTextureParameteri GLEW_GET_FUN(__glewTextureParameteri)
GLEW_FUN_EXPORT PFNGLTEXTUREPARAMETERIPROC __glewTextureParameteri
typedef void (GLAPIENTRY * PFNGLTEXTUREPARAMETERIPROC) (GLuint texture, GLenum pname, GLint param)
-
glTextureParameterIiv(int texture, int pname, Pointer<Int32> params)
→ void
-
define glTextureParameterIiv GLEW_GET_FUN(__glewTextureParameterIiv)
GLEW_FUN_EXPORT PFNGLTEXTUREPARAMETERIIVPROC __glewTextureParameterIiv
typedef void (GLAPIENTRY * PFNGLTEXTUREPARAMETERIIVPROC) (GLuint texture, GLenum pname, const GLint* params)
-
glTextureParameterIuiv(int texture, int pname, Pointer<Uint32> params)
→ void
-
define glTextureParameterIuiv GLEW_GET_FUN(__glewTextureParameterIuiv)
GLEW_FUN_EXPORT PFNGLTEXTUREPARAMETERIUIVPROC __glewTextureParameterIuiv
typedef void (GLAPIENTRY * PFNGLTEXTUREPARAMETERIUIVPROC) (GLuint texture, GLenum pname, const GLuint* params)
-
glTextureParameteriv(int texture, int pname, Pointer<Int32> param)
→ void
-
define glTextureParameteriv GLEW_GET_FUN(__glewTextureParameteriv)
GLEW_FUN_EXPORT PFNGLTEXTUREPARAMETERIVPROC __glewTextureParameteriv
typedef void (GLAPIENTRY * PFNGLTEXTUREPARAMETERIVPROC) (GLuint texture, GLenum pname, const GLint* param)
-
glTextureStorage1D(int texture, int levels, int internalformat, int width)
→ void
-
define glTextureStorage1D GLEW_GET_FUN(__glewTextureStorage1D)
GLEW_FUN_EXPORT PFNGLTEXTURESTORAGE1DPROC __glewTextureStorage1D
typedef void (GLAPIENTRY * PFNGLTEXTURESTORAGE1DPROC) (GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)
-
glTextureStorage2D(int texture, int levels, int internalformat, int width, int height)
→ void
-
define glTextureStorage2D GLEW_GET_FUN(__glewTextureStorage2D)
GLEW_FUN_EXPORT PFNGLTEXTURESTORAGE2DPROC __glewTextureStorage2D
typedef void (GLAPIENTRY * PFNGLTEXTURESTORAGE2DPROC) (GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
-
glTextureStorage2DMultisample(int texture, int samples, int internalformat, int width, int height, int fixedsamplelocations)
→ void
-
define glTextureStorage2DMultisample GLEW_GET_FUN(__glewTextureStorage2DMultisample)
GLEW_FUN_EXPORT PFNGLTEXTURESTORAGE2DMULTISAMPLEPROC __glewTextureStorage2DMultisample
typedef void (GLAPIENTRY * PFNGLTEXTURESTORAGE2DMULTISAMPLEPROC) (GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
-
glTextureStorage3D(int texture, int levels, int internalformat, int width, int height, int depth)
→ void
-
define glTextureStorage3D GLEW_GET_FUN(__glewTextureStorage3D)
GLEW_FUN_EXPORT PFNGLTEXTURESTORAGE3DPROC __glewTextureStorage3D
typedef void (GLAPIENTRY * PFNGLTEXTURESTORAGE3DPROC) (GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
-
glTextureStorage3DMultisample(int texture, int samples, int internalformat, int width, int height, int depth, int fixedsamplelocations)
→ void
-
define glTextureStorage3DMultisample GLEW_GET_FUN(__glewTextureStorage3DMultisample)
GLEW_FUN_EXPORT PFNGLTEXTURESTORAGE3DMULTISAMPLEPROC __glewTextureStorage3DMultisample
typedef void (GLAPIENTRY * PFNGLTEXTURESTORAGE3DMULTISAMPLEPROC) (GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
-
glTextureSubImage1D(int texture, int level, int xoffset, int width, int format, int type, Pointer<Void> pixels)
→ void
-
define glTextureSubImage1D GLEW_GET_FUN(__glewTextureSubImage1D)
GLEW_FUN_EXPORT PFNGLTEXTURESUBIMAGE1DPROC __glewTextureSubImage1D
typedef void (GLAPIENTRY * PFNGLTEXTURESUBIMAGE1DPROC) (GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
-
glTextureSubImage2D(int texture, int level, int xoffset, int yoffset, int width, int height, int format, int type, Pointer<Void> pixels)
→ void
-
define glTextureSubImage2D GLEW_GET_FUN(__glewTextureSubImage2D)
GLEW_FUN_EXPORT PFNGLTEXTURESUBIMAGE2DPROC __glewTextureSubImage2D
typedef void (GLAPIENTRY * PFNGLTEXTURESUBIMAGE2DPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
-
glTextureSubImage3D(int texture, int level, int xoffset, int yoffset, int zoffset, int width, int height, int depth, int format, int type, Pointer<Void> pixels)
→ void
-
define glTextureSubImage3D GLEW_GET_FUN(__glewTextureSubImage3D)
GLEW_FUN_EXPORT PFNGLTEXTURESUBIMAGE3DPROC __glewTextureSubImage3D
typedef void (GLAPIENTRY * PFNGLTEXTURESUBIMAGE3DPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
-
glTransformFeedbackBufferBase(int xfb, int index, int buffer)
→ void
-
define glTransformFeedbackBufferBase GLEW_GET_FUN(__glewTransformFeedbackBufferBase)
GLEW_FUN_EXPORT PFNGLTRANSFORMFEEDBACKBUFFERBASEPROC __glewTransformFeedbackBufferBase
typedef void (GLAPIENTRY * PFNGLTRANSFORMFEEDBACKBUFFERBASEPROC) (GLuint xfb, GLuint index, GLuint buffer)
-
glTransformFeedbackBufferRange(int xfb, int index, int buffer, int offset, int size)
→ void
-
define glTransformFeedbackBufferRange GLEW_GET_FUN(__glewTransformFeedbackBufferRange)
GLEW_FUN_EXPORT PFNGLTRANSFORMFEEDBACKBUFFERRANGEPROC __glewTransformFeedbackBufferRange
typedef void (GLAPIENTRY * PFNGLTRANSFORMFEEDBACKBUFFERRANGEPROC) (GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
-
glUnmapNamedBuffer(int buffer)
→ int
-
define glUnmapNamedBuffer GLEW_GET_FUN(__glewUnmapNamedBuffer)
GLEW_FUN_EXPORT PFNGLUNMAPNAMEDBUFFERPROC __glewUnmapNamedBuffer
typedef GLboolean (GLAPIENTRY * PFNGLUNMAPNAMEDBUFFERPROC) (GLuint buffer)
-
glVertexArrayAttribBinding(int vaobj, int attribindex, int bindingindex)
→ void
-
define glVertexArrayAttribBinding GLEW_GET_FUN(__glewVertexArrayAttribBinding)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYATTRIBBINDINGPROC __glewVertexArrayAttribBinding
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYATTRIBBINDINGPROC) (GLuint vaobj, GLuint attribindex, GLuint bindingindex)
-
glVertexArrayAttribFormat(int vaobj, int attribindex, int size, int type, int normalized, int relativeoffset)
→ void
-
define glVertexArrayAttribFormat GLEW_GET_FUN(__glewVertexArrayAttribFormat)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYATTRIBFORMATPROC __glewVertexArrayAttribFormat
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYATTRIBFORMATPROC) (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
-
glVertexArrayAttribIFormat(int vaobj, int attribindex, int size, int type, int relativeoffset)
→ void
-
define glVertexArrayAttribIFormat GLEW_GET_FUN(__glewVertexArrayAttribIFormat)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYATTRIBIFORMATPROC __glewVertexArrayAttribIFormat
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYATTRIBIFORMATPROC) (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
-
glVertexArrayAttribLFormat(int vaobj, int attribindex, int size, int type, int relativeoffset)
→ void
-
define glVertexArrayAttribLFormat GLEW_GET_FUN(__glewVertexArrayAttribLFormat)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYATTRIBLFORMATPROC __glewVertexArrayAttribLFormat
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYATTRIBLFORMATPROC) (GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
-
glVertexArrayBindingDivisor(int vaobj, int bindingindex, int divisor)
→ void
-
define glVertexArrayBindingDivisor GLEW_GET_FUN(__glewVertexArrayBindingDivisor)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYBINDINGDIVISORPROC __glewVertexArrayBindingDivisor
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYBINDINGDIVISORPROC) (GLuint vaobj, GLuint bindingindex, GLuint divisor)
-
glVertexArrayElementBuffer(int vaobj, int buffer)
→ void
-
define glVertexArrayElementBuffer GLEW_GET_FUN(__glewVertexArrayElementBuffer)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYELEMENTBUFFERPROC __glewVertexArrayElementBuffer
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYELEMENTBUFFERPROC) (GLuint vaobj, GLuint buffer)
-
glVertexArrayVertexBuffer(int vaobj, int bindingindex, int buffer, int offset, int stride)
→ void
-
define glVertexArrayVertexBuffer GLEW_GET_FUN(__glewVertexArrayVertexBuffer)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYVERTEXBUFFERPROC __glewVertexArrayVertexBuffer
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYVERTEXBUFFERPROC) (GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
-
glVertexArrayVertexBuffers(int vaobj, int first, int count, Pointer<Uint32> buffers, Pointer<Uint64> offsets, Pointer<Uint32> strides)
→ void
-
define glVertexArrayVertexBuffers GLEW_GET_FUN(__glewVertexArrayVertexBuffers)
GLEW_FUN_EXPORT PFNGLVERTEXARRAYVERTEXBUFFERSPROC __glewVertexArrayVertexBuffers
typedef void (GLAPIENTRY * PFNGLVERTEXARRAYVERTEXBUFFERSPROC) (GLuint vaobj, GLuint first, GLsizei count, const GLuint* buffers, const GLintptr *offsets, const GLsizei *strides)