glew/generated/lib_glad/lib_glad_arb_invalidate_subdata
library
Functions
-
glInvalidateBufferData(int buffer)
→ void
-
define glInvalidateBufferData GLEW_GET_FUN(__glewInvalidateBufferData)
GLEW_FUN_EXPORT PFNGLINVALIDATEBUFFERDATAPROC __glewInvalidateBufferData
typedef void (GLAPIENTRY * PFNGLINVALIDATEBUFFERDATAPROC) (GLuint buffer)
-
glInvalidateBufferSubData(int buffer, int offset, int length)
→ void
-
define glInvalidateBufferSubData GLEW_GET_FUN(__glewInvalidateBufferSubData)
GLEW_FUN_EXPORT PFNGLINVALIDATEBUFFERSUBDATAPROC __glewInvalidateBufferSubData
typedef void (GLAPIENTRY * PFNGLINVALIDATEBUFFERSUBDATAPROC) (GLuint buffer, GLintptr offset, GLsizeiptr length)
-
glInvalidateFramebuffer(int target, int numAttachments, Pointer<Uint32> attachments)
→ void
-
define glInvalidateFramebuffer GLEW_GET_FUN(__glewInvalidateFramebuffer)
GLEW_FUN_EXPORT PFNGLINVALIDATEFRAMEBUFFERPROC __glewInvalidateFramebuffer
typedef void (GLAPIENTRY * PFNGLINVALIDATEFRAMEBUFFERPROC) (GLenum target, GLsizei numAttachments, const GLenum* attachments)
-
glInvalidateSubFramebuffer(int target, int numAttachments, Pointer<Uint32> attachments, int x, int y, int width, int height)
→ void
-
define glInvalidateSubFramebuffer GLEW_GET_FUN(__glewInvalidateSubFramebuffer)
GLEW_FUN_EXPORT PFNGLINVALIDATESUBFRAMEBUFFERPROC __glewInvalidateSubFramebuffer
typedef void (GLAPIENTRY * PFNGLINVALIDATESUBFRAMEBUFFERPROC) (GLenum target, GLsizei numAttachments, const GLenum* attachments, GLint x, GLint y, GLsizei width, GLsizei height)
-
glInvalidateTexImage(int texture, int level)
→ void
-
define glInvalidateTexImage GLEW_GET_FUN(__glewInvalidateTexImage)
GLEW_FUN_EXPORT PFNGLINVALIDATETEXIMAGEPROC __glewInvalidateTexImage
typedef void (GLAPIENTRY * PFNGLINVALIDATETEXIMAGEPROC) (GLuint texture, GLint level)
-
glInvalidateTexSubImage(int texture, int level, int xoffset, int yoffset, int zoffset, int width, int height, int depth)
→ void
-
define glInvalidateTexSubImage GLEW_GET_FUN(__glewInvalidateTexSubImage)
GLEW_FUN_EXPORT PFNGLINVALIDATETEXSUBIMAGEPROC __glewInvalidateTexSubImage
typedef void (GLAPIENTRY * PFNGLINVALIDATETEXSUBIMAGEPROC) (GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)