glew/generated/lib_glad/lib_glad_arb_texture_compression
library
Functions
-
glCompressedTexImage1Darb(int target, int level, int internalformat, int width, int border, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTexImage1DARB GLEW_GET_FUN(__glewCompressedTexImage1DARB)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXIMAGE1DARBPROC __glewCompressedTexImage1DARB
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXIMAGE1DARBPROC) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
-
glCompressedTexImage2Darb(int target, int level, int internalformat, int width, int height, int border, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTexImage2DARB GLEW_GET_FUN(__glewCompressedTexImage2DARB)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXIMAGE2DARBPROC __glewCompressedTexImage2DARB
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXIMAGE2DARBPROC) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
-
glCompressedTexImage3Darb(int target, int level, int internalformat, int width, int height, int depth, int border, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTexImage3DARB GLEW_GET_FUN(__glewCompressedTexImage3DARB)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXIMAGE3DARBPROC __glewCompressedTexImage3DARB
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXIMAGE3DARBPROC) (GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
-
glCompressedTexSubImage1Darb(int target, int level, int xoffset, int width, int format, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTexSubImage1DARB GLEW_GET_FUN(__glewCompressedTexSubImage1DARB)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC __glewCompressedTexSubImage1DARB
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC) (GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
-
glCompressedTexSubImage2Darb(int target, int level, int xoffset, int yoffset, int width, int height, int format, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTexSubImage2DARB GLEW_GET_FUN(__glewCompressedTexSubImage2DARB)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC __glewCompressedTexSubImage2DARB
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
-
glCompressedTexSubImage3Darb(int target, int level, int xoffset, int yoffset, int zoffset, int width, int height, int depth, int format, int imageSize, Pointer<Void> data)
→ void
-
define glCompressedTexSubImage3DARB GLEW_GET_FUN(__glewCompressedTexSubImage3DARB)
GLEW_FUN_EXPORT PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC __glewCompressedTexSubImage3DARB
typedef void (GLAPIENTRY * PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC) (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
-
glGetCompressedTexImageArb(int target, int lod, Pointer<Void> img)
→ void
-
define glGetCompressedTexImageARB GLEW_GET_FUN(__glewGetCompressedTexImageARB)
GLEW_FUN_EXPORT PFNGLGETCOMPRESSEDTEXIMAGEARBPROC __glewGetCompressedTexImageARB
typedef void (GLAPIENTRY * PFNGLGETCOMPRESSEDTEXIMAGEARBPROC) (GLenum target, GLint lod, void *img)